@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Perlbal::Plugin::SessionAffinity;
 # ABSTRACT: Sane session affinity (sticky sessions) for Perlbal
-$Perlbal::Plugin::SessionAffinity::VERSION = '0.100';
+$Perlbal::Plugin::SessionAffinity::VERSION = '0.101';
 use Perlbal;
 use Hash::Util;
 use CGI::Cookie;
@@ -367,13 +367,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perlbal::Plugin::SessionAffinity - Sane session affinity (sticky sessions) for Perlbal
 
 =head1 VERSION
 
-version 0.100
+version 0.101
 
 =head1 SYNOPSIS
 
@@ -578,23 +580,6 @@ cookie) since backends are decided by the domain name alone.
 
 Default: B<no>.
 
-=head2 affinity_use_dynamic_cookie
-
-Allows you to provide domain-specific dynamic cookies. In case you're serving
-multiple domains and you want each one to have its own cookie, you can turn
-this feature on, and it will generate a cookie that is an MD5 of the domain,
-then wrapped in base64.
-
-    # both are equal
-    affinity_use_dynamic_cookie = 1
-    affinity_use_dynamic_cookie = yes
-
-    # opposite meaning
-    affinity_use_dynamic_cookie = 0
-    affinity_use_dynamic_cookie = no
-
-Default: B<no>.
-
 =head1 SUBROUTINES/METHODS
 
 =head2 register
@@ -672,7 +657,7 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Sawyer X.
+This software is copyright (c) 2016 by Sawyer X.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
